==> derby-0.0.5.tgz: package/lib/EventDispatcher.js <==
var EventDispatcher, hasKeys, swapQuotes;
hasKeys = require('racer').util.hasKeys;
swapQuotes = function(s) {
  return s.replace(/['"]/g, function(match) {
    if (match === '"') {
      return "'";
    } else {
      return '"';
    }
  });
};
EventDispatcher = module.exports = function(options) {
  var empty;
  if (options == null) {
    options = {};
  }
  empty = function() {};
  this._onTrigger = options.onTrigger || empty;
  this._onBind = options.onBind || empty;
  this._onUnbind = options.onUnbind || empty;
  this._names = {};
};
EventDispatcher.prototype = {
  bind: function(name, listener) {
    var key, names, obj;
    if (this._onBind(name, listener) === false) {
      return;
    }
    names = this._names;
    key = listener == null ? 'null' : JSON.stringify(listener);
    obj = names[name] || {};
    obj[key] = true;
    return names[name] = obj;
  },
  unbind: function(name, listener) {
    var names, obj;
    if (this._onUnbind(name, listener) === false) {
      return;
    }
    names = this._names;
    if (!(obj = names[name])) {
      return;
    }
    delete obj[JSON.stringify(listener)];
    if (!hasKeys(obj)) {
      return delete names[name];
    }
  },
  trigger: function(name, value, options) {
    var count, key, listener, listeners, names, onTrigger;
    names = this._names;
    listeners = names[name];
    onTrigger = this._onTrigger;
    count = 0;
    for (key in listeners) {
      count++;
      listener = JSON.parse(key);
      if (onTrigger(name, listener, value, options) !== false) {
        continue;
      }
      delete listeners[key];
      count--;
    }
    if (count === 0) {
      return delete names[name];
    }
  },
  get: function() {
    var listener, listeners, name, names, out;
    names = this._names;
    out = {};
    for (name in names) {
      listeners = names[name];
      out[name] = (function() {
        var _results;
        _results = [];
        for (listener in listeners) {
          _results.push(swapQuotes(listener));
        }
        return _results;
      })();
    }
    return out;
  },
  set: function(n) {
    var listener, listeners, name, names, obj, _results;
    names = this._names;
    _results = [];
    for (name in n) {
      listeners = n[name];
      obj = names[name] = {};
      _results.push((function() {
        var _i, _len, _results2;
        _results2 = [];
        for (_i = 0, _len = listeners.length; _i < _len; _i++) {
          listener = listeners[_i];
          _results2.push(obj[swapQuotes(listener)] = true);
        }
        return _results2;
      })());
    }
    return _results;
  }
};

==> derby-0.0.8.tgz: package/lib/EventDispatcher.js <==
var EventDispatcher, hasKeys, swapQuotes;
hasKeys = require('racer').util.hasKeys;
swapQuotes = function(s) {
  return s.replace(/['"]/g, function(match) {
    if (match === '"') {
      return "'";
    } else {
      return '"';
    }
  });
};
EventDispatcher = module.exports = function(options) {
  var empty;
  if (options == null) {
    options = {};
  }
  empty = function() {};
  this._onTrigger = options.onTrigger || empty;
  this._onBind = options.onBind || empty;
  this._onUnbind = options.onUnbind || empty;
  this._names = {};
};
EventDispatcher.prototype = {
  bind: function(name, listener) {
    var key, names, obj;
    if (this._onBind(name, listener) === false) {
      return;
    }
    names = this._names;
    key = listener == null ? 'null' : JSON.stringify(listener);
    obj = names[name] || {};
    obj[key] = true;
    return names[name] = obj;
  },
  unbind: function(name, listener) {
    var names, obj;
    if (this._onUnbind(name, listener) === false) {
      return;
    }
    names = this._names;
    if (!(obj = names[name])) {
      return;
    }
    delete obj[JSON.stringify(listener)];
    if (!hasKeys(obj)) {
      return delete names[name];
    }
  },
  trigger: function(name, value, arg0, arg1) {
    var count, key, listener, listeners, names, onTrigger;
    names = this._names;
    listeners = names[name];
    onTrigger = this._onTrigger;
    count = 0;
    for (key in listeners) {
      count++;
      listener = JSON.parse(key);
      if (onTrigger(name, listener, value, arg0, arg1) !== false) {
        continue;
      }
      delete listeners[key];
      count--;
    }
    if (count === 0) {
      return delete names[name];
    }
  },
  get: function() {
    var listener, listeners, name, names, out;
    names = this._names;
    out = {};
    for (name in names) {
      listeners = names[name];
      out[name] = (function() {
        var _results;
        _results = [];
        for (listener in listeners) {
          _results.push(swapQuotes(listener));
        }
        return _results;
      })();
    }
    return out;
  },
  set: function(n) {
    var listener, listeners, name, names, obj, _results;
    names = this._names;
    _results = [];
    for (name in n) {
      listeners = n[name];
      obj = names[name] = {};
      _results.push((function() {
        var _i, _len, _results2;
        _results2 = [];
        for (_i = 0, _len = listeners.length; _i < _len; _i++) {
          listener = listeners[_i];
          _results2.push(obj[swapQuotes(listener)] = true);
        }
        return _results2;
      })());
    }
    return _results;
  }
};
